import VectorLayer from 'ol/layer/Vector';
import VectorSource from 'ol/source/Vector';
import GeoJSON from 'ol/format/GeoJSON';
import {Circle as CircleStyle, Fill, Stroke, Style, Text, Icon} from 'ol/style';
import MapProperties from './MapProperties';

export interface TemperatureSeries{
    date: number;
    value: number;
}

export default class StationLayer{
    public static readonly layerName: string = "StationLayer";
    private layer: any;
    private mapProperties: MapProperties;
    private year: number = 2000; 

    private house = '<svg xmlns="http://www.w3.org/2000/svg" height="24px" viewBox="0 0 24 24" width="24px" fill="%color%"><path d="M0 0h24v24H0z" fill="none"/><path d="M10 20v-6h4v6h5v-8h3L12 3 2 12h3v8z"/></svg>';


    constructor(mapProperties: MapProperties){
        this.mapProperties = mapProperties;

        this.layer = new VectorLayer({
            className: StationLayer.layerName,
            source: new VectorSource({
                url: "http://localhost/germanStation.geojson",
                format: new GeoJSON(),
            }),
            style: (feature)=>{return this.stationStyle(feature)}
        })
    }

    public getLayer(): any{
        return this.layer;
    }

    protected stationStyle(feature){

        let fontSize = 15
        let label = '';
        if(this.mapProperties.getZoomLevel()>=8){
            label += feature.get("id");
        }
        
        let iconColor = "blue";
        //console.log(this.year,": ",feature.get(this.year));
        let temperature = feature.get(this.year);
        if(!temperature){
            iconColor = "black";
        }else if(temperature>10){
            iconColor = "red"
        }else{
            iconColor = "blue";
        }

        return new Style({
            text: new Text({
                font: fontSize+'px Helvetica,bold',
                overflow: true,
                fill: new Fill({
                    color: 'rgba(0,0,0,1)'
                }),
                offsetY: 0,
                text: label
            }),
            image: new Icon({
                color: "rgba(255, 0, 0, .5)",
                crossOrigin: 'anonymous',
                // For Internet Explorer 11
                imgSize: [24, 24],
                scale: 0.7,
                //src: './public/home_black_24dp.svg',
                src: 'data:image/svg+xml;utf8,'+this.house.replace("%color%", iconColor),
              })
        });
    }

    public getTemperatureSeriesFromFeature(feature: any): TemperatureSeries[]{
        let series: TemperatureSeries[] = new Array<TemperatureSeries>();
        console.log(feature);
        /* series.push({date: 2010, value: feature.get(2010)});
        series.push({date: 2011, value: feature.get(2011)});
        series.push({date: 2012, value: feature.get(2012)});
        series.push({date: 2013, value: feature.get(2013)});
        series.push({date: 2014, value: feature.get(2014)});
 */
        feature.getKeys().forEach(element => {
            if(!isNaN(element) && Number.parseInt(element)>=1800 && feature.get(element)!=null){
                series.push({date: Number.parseInt(element), value: feature.get(element)});
            }
        });
        return series;

    }

    public newYear(year: number ):void{
        this.year = year;
    }

}